@@ -6,6 +6,8 @@ import (
 
 	"github.com/spf13/cobra"
 
+	"github.com/hofstadter-io/hof/cmd/hof/ga"
+
 	"github.com/hofstadter-io/hof/lib"
 )
 
@@ -42,6 +44,12 @@ var FeedbackCmd = &cobra.Command{
 
 	Long: feedbackLong,
 
+	PreRun: func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath())
+
+	},
+
 	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
@@ -76,7 +84,15 @@ func init() {
 		return ousage(cmd)
 	}
 
-	FeedbackCmd.SetHelpFunc(help)
-	FeedbackCmd.SetUsageFunc(usage)
+	thelp := func(cmd *cobra.Command, args []string) {
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+		help(cmd, args)
+	}
+	tusage := func(cmd *cobra.Command) error {
+		ga.SendCommandPath(cmd.CommandPath() + " usage")
+		return usage(cmd)
+	}
+	FeedbackCmd.SetHelpFunc(thelp)
+	FeedbackCmd.SetUsageFunc(tusage)
 
 }
