@@ -7,6 +7,7 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/hofstadter-io/hof/cmd/hof/flags"
+	"github.com/hofstadter-io/hof/cmd/hof/ga"
 
 	"github.com/hofstadter-io/hof/lib/ops"
 )
@@ -49,6 +50,12 @@ var RunCmd = &cobra.Command{
 
 	Long: runLong,
 
+	PreRun: func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath())
+
+	},
+
 	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
@@ -83,7 +90,15 @@ func init() {
 		return ousage(cmd)
 	}
 
-	RunCmd.SetHelpFunc(help)
-	RunCmd.SetUsageFunc(usage)
+	thelp := func(cmd *cobra.Command, args []string) {
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+		help(cmd, args)
+	}
+	tusage := func(cmd *cobra.Command) error {
+		ga.SendCommandPath(cmd.CommandPath() + " usage")
+		return usage(cmd)
+	}
+	RunCmd.SetHelpFunc(thelp)
+	RunCmd.SetUsageFunc(tusage)
 
 }
