@@ -27,12 +27,7 @@ var funcMap = template.FuncMap{
 	"toml": Helper_toml,
 	"xml":  Helper_xml,
 
-	"concat": Helper_concat,
-	"join":   Helper_join,
-
 	"indent": Helper_indent,
-	"lwidth": Helper_lwidth,
-	"rwidth": Helper_rwidth,
 	"pprint": Helper_pretty,
 	"pretty": Helper_pretty,
 
@@ -50,6 +45,8 @@ var funcMap = template.FuncMap{
 	"KEBAB":  Helper_kebabU,
 	"kebabU": Helper_kebabU,
 
+	"concat":         Helper_concat,
+	"join":           Helper_join,
 	"contains":       Helper_contains,
 	"split":          Helper_split,
 	"replace":        Helper_replace,
@@ -73,6 +70,9 @@ var funcMap = template.FuncMap{
 	"dict":     Helper_dict,
 	"file":     Helper_file,
 
+	"add":     Helper_add,
+	"inc":     Helper_inc,
+
 	"gokind":  Helper_gokind,
 	"builtin": Helper_builtin,
 
@@ -145,16 +145,6 @@ func Helper_indent(value, indent string) string {
 	return ret
 }
 
-func Helper_lwidth(width string, value string) string {
-	fmt_str := "%-" + width + "s"
-	return fmt.Sprintf(fmt_str, value)
-}
-
-func Helper_rwidth(width string, value string) string {
-	fmt_str := "%-" + width + "s"
-	return fmt.Sprintf(fmt_str, value)
-}
-
 func Helper_pretty(value interface{}) string {
 	return fmt.Sprintf("%# v", pretty.Formatter(value))
 }
@@ -352,6 +342,13 @@ func Helper_file(filename string) string {
 	return fmt.Sprintf("ERROR: %v", err)
 }
 
+func Helper_add(lhs, rhs int) int {
+	return lhs + rhs
+}
+
+func Helper_inc(val int) int {
+	return val + 1
+}
 func Helper_gokind(input interface{}) string {
 	v := reflect.ValueOf(input)
 	k := v.Kind()
@@ -396,6 +393,12 @@ func Helper_lookup(path string, data interface{}) interface{} {
 		return fmt.Sprint("Nil data supplied for " + path)
 	}
 
+	// if OpenAPI format, convert to dotpath
+	if strings.HasPrefix(path, "#/") {
+		path = path[2:]
+		path = strings.Replace(path, "/", ".", -2)
+	}
+
 	obj, err := dotpath.Get(path, data, true)
 	if err != nil {
 		return fmt.Sprint("Error during path search: " + err.Error())
